#!/bin/bash
#

# buildTBB.sh <opt|debug|prof> [e2|gcc47]
# default is gcc47

extraqual=${1}
basequal=${2}

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

pkgver=v4_1_1
pkgtarname=tbb41_20121003oss
gccdotver=4.7
gccver=v4_7_1


if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    reltype="release"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    reltype="debug"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    reltype="release"
else
   echo "ERROR: please specify debug, opt, or prof"
   echo "USAGE: buildLhapdf.sh <opt|debug|prof> [e2|gcc47]"
   exit 1
fi
if [ "${basequal}" = "e2" ] 
then
  extra_command="cpp0x=1"
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi
pkgdir=${PRODUCTS}/tbb/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/tbb/${pkgver}/source

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi

# TBB requires an in-source build
cd ${pkgdir}
tar xf ${sourcedir}/${pkgtarname}_src.tgz

set -x

cd ${pkgdir}/${pkgtarname}/src

make tbb_build_dir=${pkgdir}/build ${extra_command} ${reltype} 

set +x

mkdir -p ${pkgdir}/lib
if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi
if [ "${extraqual}" = "debug" ]
then
   mv ${pkgdir}/build/lin*/lib*.so.* ${pkgdir}/lib/
   cd ${pkgdir}/lib
   ln -s libtbb_debug.so.2 libtbb.so
   ln -s libtbbmalloc_debug.so.2 libtbbmalloc.so
   ln -s libtbbmalloc_proxy_debug.so.2 libtbbmalloc_proxy.so
else
   mv ${pkgdir}/build/lin*/lib*.so.* ${pkgdir}/lib/
   cd ${pkgdir}/lib
   ln -s libtbb.so.2 libtbb.so
   ln -s libtbbmalloc.so.2 libtbbmalloc.so
   ln -s libtbbmalloc_proxy.so.2 libtbbmalloc_proxy.so
fi

# cmake configure files
cp -pr ${sourcedir}/tbb ${pkgdir}/lib/

# this should not complain
   echo "Finished building tbb for flavor ${flvr}"
   echo "Declaring tbb ${pkgver} for ${flvr} and ${fullqual}"
OS=`uname`
if [ ${OS} = "Darwin" ]
then
   ups declare tbb ${pkgver} -r tbb/${pkgver} -2 -m tbb.table -q ${fullqual}
else 
   ups declare tbb ${pkgver} -r tbb/${pkgver} -4 -m tbb.table -q ${fullqual}
fi
setup tbb ${pkgver} -q ${fullqual}
echo "tbb is installed at ${LHAPDF_FQ_DIR}"

exit 0
